package com.kuyuntech.cofarcooking.device.sdk.devmode.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.*;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.core.DevInfo;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.event.Dev2McuDataDevEvent;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.event.DevPromptEvent;
import com.kuyuntech.cofarcooking.device.sdk.eventbus.listener.Dev2McuDevEventListener;
import com.kuyuntech.cofarcooking.device.sdk.util.core.CofarSDK;

import java.util.TimerTask;

public class Ferment010D extends BaseDevMode{


    private String stage = Ferment010DStage.FIRST;

    public Ferment010D(){

        this.setMode(WorkModes.FERMENT);

        this.reset();

    }


    public void reset(){

        this.stage = Ferment010DStage.FIRST;

        //时间
        this.setMinTime(0);
        this.setMaxTime(0);
        this.setDefaultTime(0);
        this.setTimeChange(false);
        CofarSDK.cfgTimeNatvie(0);

        //电机
        this.setDefaultMotorGear(0);
        this.setMaxMotorGear(0);
        this.setMinMotorGear(0);
        this.setMotorGearChange(false);
        this.setMotorDirectionChange(false);
        this.setMotorDirection(MotorDirections.FORWARD);

        //温度
        this.setDefaultTemp(100);
        this.setMinTemp(0);
        this.setMaxTemp(100);
        this.setTimeChange(false);
        this.setDefaultHeatMode(HeatModes.SAP_SHUI);
        CofarSDK.cfgHeatNative((short) 100,HeatModes.SAP_SHUI);

        this.setDiyCountDown(true);
    }

    @Override
    public void stop(){
        this.reset();
        super.stop();
    }

    @Override
    public void start(){
        super.start();
    }


    @Override
    public boolean isTempChange() {

        if(this.stage.equals(Ferment010DStage.FIRST)){
            return false;
        }

        if(this.stage.equals(Ferment010DStage.SECOND)){
            return false;
        }

        if(this.stage.equals(Ferment010DStage.THIRD)){
            return true;
        }

        return this.isTempChange();

    }



    @Override
    public int getMaxTime() {

        if(this.stage.equals(Ferment010DStage.FIRST)){
            return 0;
        }

        if(this.stage.equals(Ferment010DStage.SECOND)){
            return 5 * 60;
        }

        if(this.stage.equals(Ferment010DStage.THIRD)){
            return 10 * 60 * 60;
        }

        return this.getMaxTime();

    }


    @Override
    public boolean isTimeChange() {

        if(this.stage.equals(Ferment010DStage.FIRST)){
            return false;
        }

        if(this.stage.equals(Ferment010DStage.SECOND)){
            return false;
        }

        if(this.stage.equals(Ferment010DStage.THIRD)){
            return true;
        }

        return super.isTimeChange();
    }

    @Override
    public int getMinTime() {

        if(this.stage.equals(Ferment010DStage.FIRST)){
            return 0;
        }

        if(this.stage.equals(Ferment010DStage.SECOND)){
            return 5 * 60;
        }

        if(this.stage.equals(Ferment010DStage.THIRD)){
            return 8 * 60 * 60;
        }

        return this.getMaxTime();

    }



    @Override
    public void onCountDown(TimerTask timer) {

        DevInfo devInfo =  CofarSDK.devInfo();

        if(this.isPauseFlag()){
           return;
        }


        if(this.stage.equals(Ferment010DStage.FIRST)){

            if(devInfo.getTemp() >= 100){
                if(devInfo.getStatus()  == DevStatus.RUNNING){
                    this.pause();
                }
                DevPromptEvent.Callback confirm = () -> {
                    this.stage = Ferment010DStage.SECOND;
                    this.setPauseFlag(false);
                    CofarSDK.cfgTimeNatvie(5 * 60);
                    CofarSDK.cfgHeatNative((short) 100,HeatModes.PU_TONG);
                    CofarSDK.startNative();
                };

                CofarSDK.promptUp(DevPromptEvent.builder().msg("frement_010d_stage_first_finish").showCancelBtn(false).showConfirmBtn(true).confirm(confirm).build());
            }else{
                devInfo.setRemainTime(devInfo.getRemainTime() + 1);
            }
        }


        if(this.stage.equals(Ferment010DStage.SECOND)){

            if(devInfo.getRemainTime() > 0){
                devInfo.setRemainTime(devInfo.getRemainTime() - 1);
            }else{
                this.stage = Ferment010DStage.THIRD;
                CofarSDK.cfgHeatNative((short) 5,HeatModes.PU_TONG);
                CofarSDK.cfgTimeNatvie(8 * 60 * 60);
                CofarSDK.startNative();
            }
        }


        if(this.stage.equals(Ferment010DStage.THIRD)){

            if(devInfo.getRemainTime() > 0){
                devInfo.setRemainTime(devInfo.getRemainTime() - 1);
            }else{
                this.stop();
            }
        }


    }


}
