package com.kuyuntech.cofarcooking.device.sdk.eventbus.core;

import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevModes;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.DevStatus;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.PotTypes;
import com.kuyuntech.cofarcooking.device.sdk.constant.core.SupportWaterSprayStatus;
import com.kuyuntech.cofarcooking.device.sdk.devmode.core.AdaptedCooking;
import com.kuyuntech.cofarcooking.device.sdk.devmode.core.BaseDevMode;
import lombok.*;

import java.io.Serializable;

@Data
@ToString
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class DevInfo implements Cloneable, Serializable {

    @Builder.Default
    private boolean initStatus = false;

    private String currentScene;

    //状态
    private int status = DevStatus.STOP;

    //电机方向
    private byte motorDirection;

    //电机方向缓存
    @Builder.Default
    private byte motorDirectionBuffer = -1;

    //电机档位
    private byte motorGear;

    //电机档位缓存
    @Builder.Default
    private byte motorGearBuffer = -1;

    //是否AUTO档
    private byte autoGear;

    //加热模式
    private byte heatMode;

    //当前温度
    private short temp;

    //真实温度
    private short realTemp;

    //设置目标温度
    private short targetTemp;

    //目标温度缓存
    @Builder.Default
    private short targetTempBuffer = -1;

    //剩下时长
    private int remainTime;

    //设定时长
    private int targetTime;

    //目标时长缓存
    @Builder.Default
    private int targetTimeBuffer = -1;

    //锅状态
    private byte potStatus;

    //锅盖状态
    private byte potCloverStatus;

    //故障代码
    private byte errCode;

    //置零
    private byte resetZero;

    //当前运行状态
    private byte runningStatus;

    //锅盖电磁阀状态
    private byte potCloverEleStatus;

    //锅盖类型
    private byte potCloverType = PotTypes.SOUP;

    //是否支持喷水
    private byte supportWaterSpray = SupportWaterSprayStatus.NO;

    //喷水档位
    private byte waterSprayGear;

    //当前模式
    @Builder.Default
    private BaseDevMode mode = new AdaptedCooking();

    //称重状态
    private boolean weightStatus = false;

    //称重数据
    private short weight;

    //标定状态
    private byte weightAlignStatus;

    //标定负载点
    private byte weightPol;

    //厂商
    private short manufacturer;

    //硬件版本
    private short haradware;

    //软件版本
    private short software;

    //通讯协议版本
    private byte protocol;

    //设备种类
    private byte devType;


    @Builder.Default
    private boolean arrive37Temp = false;


    //当前运行菜谱
    @Builder.Default
    private String runningRecipeId = "";

    //当前运行菜谱拓展数据
    @Builder.Default
    private String runningRecipeExt = "";


    @Builder.Default
    private String runningInstId = "";

    @Builder.Default
    private String settingInstId = "";


    @Builder.Default
    private String devMode = DevModes.SOUP;

    @Builder.Default
    private Integer waterGear = 0;

    @Builder.Default
    private Integer waterGearBuffer = -1;


    @Builder.Default
    private byte lastPotStatus = 0;

}

